import {NgModule} from '@angular/core';
import {PreloadAllModules, RouterModule, Routes} from '@angular/router';

import {EnvironmentSpecificResolver} from './openaireLibrary/utils/properties/environmentSpecificResolver';
import {EnvironmentSpecificService} from './openaireLibrary/utils/properties/environment-specific.service';

import {OpenaireErrorPageComponent} from './error/errorPage.component';

const routes: Routes = [
  {
    path: 'reload',
    loadChildren: './reload/libReload.module#LibReloadModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasSidebar: false, hasHeader: false}
  },
  {
    path: 'user-info',
    loadChildren: './login/libUser.module#LibUserModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasSidebar: false, isFrontPage: true}
  },
  {
    path: 'error',
    component: OpenaireErrorPageComponent,
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasSidebar: false, isFrontPage: true}
  },
  {
    path: 'admin',
    loadChildren: './manageStakeholders/manageStakeholders.module#ManageStakeholdersModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasAdminMenu: true}
  },
  {
    path: 'admin/:stakeholder/users',
    loadChildren: './users/users.module#UsersModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasAdminMenu: true},
    pathMatch: 'full'
  },
  {
    path: 'admin/:stakeholder',
    loadChildren: './general/general.module#GeneralModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasAdminMenu: true},
    pathMatch: 'full'
  },
  {
    path: 'admin/:stakeholder/indicators/:topic',
    loadChildren: './topic/topic.module#TopicModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    pathMatch: 'full'
  },
  {
    path: 'admin/:stakeholder/indicators',
    loadChildren: './topic/topic.module#TopicModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    pathMatch: 'full'
  },

  /* Library paths*/

  {
    path: 'admin-tools',
    loadChildren: './admin-tool/admin-tool-routing.module#AdminToolRoutingModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
  },
  { path: 'theme', loadChildren: './openaireLibrary/utils/theme/theme.module#ThemeModule'},
  {
    path: '',
    loadChildren: './monitor/monitor.module#MonitorModule',
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {isFrontPage: true}
  },
  {
    path: '**',
    pathMatch: 'full',
    component: OpenaireErrorPageComponent,
    resolve: {envSpecific: EnvironmentSpecificResolver},
    data: {hasSidebar: false, hasAdminMenu: false, isFrontPage: true}
  }
];

@NgModule({
  imports: [RouterModule.forRoot(routes, {
    preloadingStrategy: PreloadAllModules,
    scrollPositionRestoration: "top",
    onSameUrlNavigation: "reload"
  })],
  exports: [RouterModule],
  providers: [EnvironmentSpecificResolver, EnvironmentSpecificService]
})
export class AppRoutingModule {
}
